import { Injectable } from "@angular/core";
import { HttpClient } from "@angular/common/http";
import { environment } from "../../../environments/environment";
import { Observable } from "rxjs";
import { CapabilityRequest } from "../model/capability-request";
import { CapabilityExecution } from "../model/capability-execution";

@Injectable({
  providedIn: "root",
})
export class CapabilityLauncherService {
  private endpoint = "capability/";

  constructor(private httpClient: HttpClient) {}

  /**
   * Create capability request and send it to capability service
   * @param: capabilityName  Name of capability to create request for
   * @param: parameters  Parameters for capability request
   */
  createRequest(
    capabilityName: string,
    parameters: string
  ): Observable<CapabilityRequest> {
    const url =
      environment.workspacesUrl +
      this.endpoint +
      capabilityName +
      "/request/create";
    const requestParams = JSON.stringify({
      parameters: parameters,
    });
    return this.httpClient.post<CapabilityRequest>(url, requestParams);
  }

  /**
   * Submit capability request
   * @param: requestId  ID of capability request to submit
   */
  submit(
    capabilityName: string,
    requestId: string
  ): Observable<CapabilityExecution> {
    const url = `${environment.workspacesUrl}${this.endpoint}${capabilityName}/request/${requestId}/submit`;
    return this.httpClient.post<CapabilityExecution>(url, null);
  }
}
